@@ -145,7 +145,7 @@ class TableManager:
             schema_string = f"\\{schema_name}"
 
 
-        
+
         self.table_data = tb
         # f"{db_path}{schema_string}\\{table_name}"
         self.settings['db_path'] = db_path
@@ -186,6 +186,7 @@ class TableManager:
         self.data['unique_keys'] = obj.get_arg(tb,['unique_keys'],[],(list))
         self.data['keys'] = obj.get_arg(tb,['keys'],[],(list))
         self.data['constraints'] = obj.get_arg(tb,['constraints'],[],(list))
+        # self.data['content_hash'] = obj.get_arg(tb,['content_hash'],csu.gen.to_hash(self.settings['raw_statement']),(str))
         self.data['content_hash'] = obj.get_arg(tb,['content_hash'],None,(str))
         self.data['default_insert_data'] = obj.get_arg(tb,['default_insert_data'],[],(str))
         self.data['test_insert_data'] = obj.get_arg(tb,['test_insert_data'],[],(str))
@@ -223,6 +224,7 @@ class TableManager:
 
         # self.confirm_local_resources()
         self.generate_table_local_resources()
+
         # @Mstep [] confirm the test files exist.
         # self.confirm_test_files()
         # if cfu.exists(self.settings["insert_tmp_sql_path"]):
@@ -269,6 +271,15 @@ class TableManager:
             if self.create_sql_exists is False:
                 # @Mstep [] create the file.
                 self.gen_create_sql()
+            else:
+                if _has_create_changed(self) is True:
+                    self.gen_create_sql()
+                    
+            # @Mstep [IF] if the create file exists.
+            # if self.create_sql_exists is True:
+            #     # @Mstep [] create the file.
+            #     self.gen_create_sql()
+
 
             self.default_data_manager.import_data()
             self.test_data_manager.import_data()
@@ -372,8 +383,6 @@ class TableManager:
         return self.default_data_manager.insert_data
         # return self.data['default_insert_data']
 
-
-
     def gen_test_reset(self):
         '''
             Generate the test data insert SQL and sync the new data to the database.
@@ -688,7 +697,6 @@ class TableManager:
         return _dirs.delete(self.table_dir_path)
 
 
-
     def insert_data(self,data,overwrite=False):
         '''
             Insert a new row or rows into the default data json file.
@@ -1154,7 +1162,7 @@ class TableManager:
             * @xxx [06-05-2022 18:41:35]: documentation for table_summary_json_path
         '''
 
-        
+
         return self.settings['table_summary_json_path']
 
     @property
@@ -1204,10 +1212,13 @@ class TableManager:
 
         if self.settings['raw_statement'] is not None:
             sql = self.settings['raw_statement']
+            sql = f"--====================================================================== CREATE\n\n\n{sql}"
             sql = gen_drop_table(self.name,self.schema,sql)
             sql = prepend_header(None,sql)
-            self.settings['content_hash'] = csu.gen.to_hash(sql)
+            self.data['content_hash'] = csu.gen.to_hash(self.settings['raw_statement'])
+            
             cfu.writer.write(self.create_sql_path,sql)
+            # self.main.update_table_summary(self.name,self.table_summary)
             return True
         return False
 
@@ -1309,6 +1320,42 @@ class TableManager:
             names.append(col_data['name'])
         return names
 
+
+    @property
+    def column_data(self)->list:
+        '''
+            Get a list of this table's columns and their meta data.
+
+            ----------
+
+            Return {list}
+            ----------------------
+            A list of this table's column names.
+
+            {
+                "name": "amount",\n
+                "type": "int",\n
+                "allow_nulls": false,\n
+                "comment": "Amount (in cents) to be transferred to your bank account or debit card.",\n
+                "default": null,\n
+                "is_primary_key": false\n
+            },
+
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 06-05-2022 18:43:57
+            `memberOf`: TableManager
+            `version`: 1.0
+            `method_name`: column_names
+            * @xxx [06-05-2022 18:45:53]: documentation for column_names
+        '''
+        return self.table_meta_data
+
+
+
+
     @property
     def table_meta_data(self)->list:
         if self.data['columns'] is None:
@@ -1345,6 +1392,17 @@ class TableManager:
 
         return self.settings['table_name']
 
+
+def _has_create_changed(table:TableManager):
+    prev_hash = table.data['content_hash']
+    current_hash = csu.gen.to_hash(table.settings['raw_statement'])
+    if prev_hash != current_hash:
+        # print(f"    sql has changed, regenerating create SQL for {table.name}")
+        # print(f"    prev: {prev_hash}")
+        # print(f"    curr: {current_hash}")
+        return True
+    return False
+
 def get_column_by_name(table,col):
     for c in table.data['column_data']:
         if c['name'] == col:
