@@ -265,6 +265,17 @@ def get_arg(args:dict,key_name:_Union[list,str],default_val=False, value_type=No
     if isinstance(key_name, list) is False:
         key_name = [key_name]
 
+    # @Mstep [] first check to see if there is an exact match in the args.
+    # @Mstep [LOOP] iterate the key names
+    for name in key_name:
+        if name in args:
+            if value_type is not None:
+                if isinstance(args[name], value_type) is True:
+                    return args[name]
+            else:
+                return args[name]
+
+    # @Mstep [] if no exact matches were found, now we generate variations to test for.
     for name in key_name:
         # generate basic variations of the name
         varis = gen_variations(name)
@@ -736,3 +747,42 @@ class NestedNamespace(SimpleNamespace):
                 self.__setattr__(key, NestedNamespace(value))
             else:
                 self.__setattr__(key, value)
+
+
+def has_method(class_instance,method_name):
+    '''
+        Check to see if the class has a method.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `class_instance` {class}
+            The class to test.
+            
+        `method_name` {str}
+            The name of the method to search for
+
+
+        Return {bool}
+        ----------------------
+        True if the method exists on the class, False otherwise.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-04-2022 10:50:58
+        `memberOf`: dict_utils
+        `version`: 1.0
+        `method_name`: has_method
+        * @xxx [07-04-2022 10:52:26]: documentation for has_method
+    '''
+
+
+    result = getattr(class_instance, method_name, None)
+    if result is not None:
+        if callable(result):
+            return True
+    return False
+
+
