@@ -21,10 +21,12 @@ import re
 import shlex
 import sqlparse
 from pyparsing import And, Suppress,Dict, Word, Literal, Group, Optional, ZeroOrMore, OneOrMore, Regex, restOfLine, alphanums,nums, printables, string, CaselessKeyword,nestedExpr,ParseException,quotedString,removeQuotes,originalTextFor,delimitedList,QuotedString
-import utils.files.file as cfu
+# import utils.files.file as cfu
+import utils.file_utils as cfu
 # # from sqlparse import sql
-import utils.string_format as mod
-import utils.object_utils as obj
+import utils.string_utils as mod
+import utils.dict_utils as obj
+import utils.list_utils as lu
 
 sql_data_types = [
     "mediumtext",
@@ -716,7 +718,7 @@ def parse_column_data(value=None):
                     new_data['allow_nulls'] = True
                     continue
             if isinstance(v,(list)):
-                v = mod.strip_any(v[0],["'",'"'])
+                v = mod.strip(v[0],["'",'"'])
                 new_data[k] = v
                 continue
             new_data[k] = v
@@ -845,18 +847,19 @@ def _parse_table_column_lines(lines):
     for line in lines:
         # print(f"line: {line}")
         if is_line_key(line):
+            
             # print(f"key found: {line} {parse_key(line)}")
-            data['keys'] = obj.append(data['keys'],parse_key(line))
+            data['keys'] = lu.append(data['keys'],parse_key(line))
             pk = parse_primary_key(line)
             if pk is not None:
-                data['primary_keys'] = obj.append(data['primary_keys'],pk['primary_key'])
-            # data['primary_keys'] = obj.append(data['primary_keys'],parse_primary_key(line))
+                data['primary_keys'] = lu.append(data['primary_keys'],pk['primary_key'])
+            # data['primary_keys'] = lu.append(data['primary_keys'],parse_primary_key(line))
 
         if is_line_constraint(line):
-            data['constraints'] = obj.append(data['constraints'],parse_constraint(line))
+            data['constraints'] = lu.append(data['constraints'],parse_constraint(line))
 
 
-        data['columns'] = obj.append(data['columns'],parse_column_data(line))
+        data['columns'] = lu.append(data['columns'],parse_column_data(line))
 
         # parse_column_data(line)
     # data['keys'] = keys
@@ -895,7 +898,7 @@ def capture_create_table_columns(sql):
     output = []
     scanner = originalTextFor(nestedExpr('(',')'))
     for match in scanner.searchString(sql):
-        val = mod.strip_any(match[0],["(",")"])
+        val = mod.strip(match[0],["(",")"])
         val = escape_quoted_chars(val,True)
         output = val.split("\n")
     return output
@@ -909,7 +912,7 @@ def parse_list(value):
     # print(f"value: {value}")
     value = strip_sql_quotes(value[0])
     vals = value.split(",")
-    vals = [mod.strip_any(x,[" "]) for x in vals]
+    vals = [mod.strip(x,[" "]) for x in vals]
     return ','.join(vals)
 
 def parse_key(value=None):
@@ -1062,7 +1065,7 @@ def parse_table_columns(sql):
     '''
 
     if cfu.exists(sql):
-        sql = cfu.read.read(sql)
+        sql = cfu.readr(sql)
     # orig_sql = sql
     file_data = strip_keys_constraints(sql)
     file_data['columns'] = {}
@@ -1217,10 +1220,11 @@ def parse_allow_null(col_data):
         `method_name`: parse_allow_null
         @xxx [05-31-2022 07:31:12]: documentation for parse_allow_null
     '''
-    from utils.parse_utils import array_in_string
+
     nn_found = False
     for s in col_data['shlexed']:
-        if array_in_string(["not null","NOT NULL"],s,False):
+
+        if mod.array_in_string(["not null","NOT NULL"],s,False):
             nn_found = True
     if nn_found is False:
         col_data['allow_nulls'] = True
@@ -1260,7 +1264,7 @@ def parse_col_comment(col_data):
         if s.lower().startswith('comment'):
             # re.replace(r'^comment\s*')
             cmt = s.replace('comment','')
-            col_data['comment'] = mod.strip_any(cmt,[" "])
+            col_data['comment'] = mod.strip(cmt,[" "])
             break
 
     return col_data
@@ -1480,7 +1484,7 @@ def parse_primary_keys(sql):
         if len(match) > 0:
             keys = strip_sql_quotes(match[0])
             keys = keys.split(",")
-            keys = [mod.strip_any(x,[" "]) for x in keys]
+            keys = [mod.strip(x,[" "]) for x in keys]
             primary_keys = keys
         # print(match)
     return primary_keys
@@ -1512,7 +1516,7 @@ def format_sql_string(sql):
         @xxx [03-21-2022 12:38:41]: documentation for format_sql_string
     '''
     if cfu.exists(sql):
-        sql = cfu.read.read(sql)
+        sql = cfu.readr(sql)
 
     sql = mod.strip_empty_lines(sql)
 
@@ -1559,7 +1563,7 @@ def get_statements(sql):
     raw = sql
     if isinstance(sql,(str)):
         if cfu.exists(sql):
-            raw = cfu.read.read(sql)
+            raw = cfu.readr(sql)
 
     raw = strip_comments(raw)
     raw = escape_quoted_chars(raw)
@@ -1579,7 +1583,7 @@ def determine_statement_purpose(statement):
 
 def parse(sql):
     if cfu.exists(sql):
-        sql = cfu.read.read(sql)
+        sql = cfu.readr(sql)
 
     if len(sql)== 0:
         return None
@@ -1606,7 +1610,7 @@ def parse(sql):
 
         if state['purpose'] == "CREATE TABLE":
             state['data'] = parse_table_statement(state['raw'])
-            obj.append(data['tables'],state['data'])
+            lu.append(data['tables'],state['data'])
             continue
 
         # if state['purpose'] == "DROP TABLE":
@@ -1614,7 +1618,7 @@ def parse(sql):
 
         if state['purpose'] == "CREATE SCHEMA":
             state['data'] = parse_schema_statement(state['raw'])
-            obj.append(data['schemas'],state['data'])
+            lu.append(data['schemas'],state['data'])
             continue
 
         data['statements'].append(state)
