@@ -24,6 +24,7 @@ import utils.string_utils.string_format as mod
 import utils.string_utils.string_generation as gen
 import utils.string_utils.string_escaping as escape
 import utils.string_utils.string_strip as stripp
+import utils.string_utils.string_parsing as parse
 
 
 
@@ -32,6 +33,7 @@ from utils.string_utils.string_format import *
 from utils.string_utils.string_conversion import *
 from utils.string_utils.string_escaping import *
 from utils.string_utils.string_strip import *
+from utils.string_utils.string_parsing import *
 
 
 
